using Microsoft.Extensions.Configuration;
using Castle.MicroKernel.Registration;
using Abp.Events.Bus;
using Abp.Modules;
using Abp.Reflection.Extensions;
using MeetingSchedule.Configuration;
using MeetingSchedule.EntityFrameworkCore;
using MeetingSchedule.Migrator.DependencyInjection;

namespace MeetingSchedule.Migrator
{
    [DependsOn(typeof(MeetingScheduleEntityFrameworkModule))]
    public class MeetingScheduleMigratorModule : AbpModule
    {
        private readonly IConfigurationRoot _appConfiguration;

        public MeetingScheduleMigratorModule(MeetingScheduleEntityFrameworkModule abpProjectNameEntityFrameworkModule)
        {
            abpProjectNameEntityFrameworkModule.SkipDbSeed = true;

            _appConfiguration = AppConfigurations.Get(
                typeof(MeetingScheduleMigratorModule).GetAssembly().GetDirectoryPathOrNull()
            );
        }

        public override void PreInitialize()
        {
            Configuration.DefaultNameOrConnectionString = _appConfiguration.GetConnectionString(
                MeetingScheduleConsts.ConnectionStringName
            );

            Configuration.BackgroundJobs.IsJobExecutionEnabled = false;
            Configuration.ReplaceService(
                typeof(IEventBus), 
                () => IocManager.IocContainer.Register(
                    Component.For<IEventBus>().Instance(NullEventBus.Instance)
                )
            );
        }

        public override void Initialize()
        {
            IocManager.RegisterAssemblyByConvention(typeof(MeetingScheduleMigratorModule).GetAssembly());
            ServiceCollectionRegistrar.Register(IocManager);
        }
    }
}
